@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Login Screen
 #
-# $Id: lonlogin.pm,v 1.94 2007/08/30 22:07:45 albertel Exp $
+# $Id: lonlogin.pm,v 1.94.2.1 2007/10/09 16:48:51 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -158,9 +158,8 @@ ENDFAILED
     my $otherserver= &Apache::lonnet::absolute_url($host_name);
     my $firsturl=
     ($env{'request.firsturl'}?$env{'request.firsturl'}:$env{'form.firsturl'});
-# ---------------------------------------- Are we access server and overloaded?
-    if (($role eq 'access') &&
-	(($userloadpercent>100.0)||($loadpercent>100.0))) {
+# ---------------------------------------------------------- Are we overloaded?
+    if ((($userloadpercent>100.0)||($loadpercent>100.0))) {
         my $unloaded=Apache::lonnet::spareserver($loadpercent,$userloadpercent);
 	if ($unloaded) { $otherserver=$unloaded; }
     }
