@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # User Roles Screen
 #
-# $Id: lonroles.pm,v 1.177 2007/04/17 15:44:58 www Exp $
+# $Id: lonroles.pm,v 1.179 2007/09/10 16:07:32 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -201,7 +201,7 @@ sub handler {
 				 }
 				 $r->print(<<ENDENTEREDKEY);
 $start_page
-<script>
+<script type="text/javascript">
 $swinfo
 </script>
 <form method="post">
@@ -224,7 +224,7 @@ ENDENTEREDKEY
 				 my $end_page=&Apache::loncommon::end_page();
 				 $r->print(<<ENDENTERKEY);
 $start_page
-<script>
+<script type="text/javascript">
 $swinfo
 </script>
 <form method="post">
@@ -365,11 +365,15 @@ ENDENTERKEY
     my $start_page=&Apache::loncommon::start_page('User Roles');
     my $standby=&mt('Role selected. Please stand by.');
     $standby=~s/\n/\\n/g;
+    my $noscript='<span class="LC_error">'.&mt('Use of LON-CAPA requires Javascript to be enabled in your web browser.').'<br />'.&mt('As this is not the case, most functionality in the system will ba unavailable.').'</span><br />';
 
     $r->print(<<ENDHEADER);
 $start_page
 <br />
-<script>
+<noscript>
+$noscript
+</noscript>
+<script type="text/javascript">
 $swinfo
 window.focus();
 
@@ -443,14 +447,6 @@ ENDHEADER
 		  &Apache::loncommon::end_page());
 	return OK;
     } else {
-        if ($advanced) {
-	    $r->print('<span class="LC_rolesinfo">'.&mt("Your home server is ").
-		      &Apache::lonnet::hostname(&Apache::lonnet::homeserver
-                      ($env{'user.name'},$env{'user.domain'})).
-		      "<br />\n");
-	    $r->print(&mt(
-      "Author and Co-Author roles are not available on servers other than their respective home servers.").'</span>');
-        }
         if (($ENV{'REDIRECT_QUERY_STRING'}) && ($fn)) {
     	    $fn.='?'.$ENV{'REDIRECT_QUERY_STRING'};
         }
@@ -636,10 +632,11 @@ ENDHEADER
 # Is there only one choice?
     } elsif (($countactive==1) && ($env{'request.role'} eq 'cm')) {
 	$r->print('<h3>'.&mt('Please stand by.').'</h3>'.
-	    '<input type="hidden" name="'.$possiblerole.'" value="1" />');
+	    '<input type="hidden" name="'.$possiblerole.'" value="1" />'.
+            '<noscript><br /><input type="submit" name="submit" value="'.&mt('Continue').'" /></noscript>');
 	$r->print("</form>\n");
 	$r->rflush();
-	$r->print('<script>document.forms.rolechoice.submit();</script>');
+	$r->print('<script type="text/javascript">document.forms.rolechoice.submit();</script>');
 	$r->print(&Apache::loncommon::end_page());
 	return OK;
     }
@@ -934,7 +931,7 @@ sub courselink {
 
 sub coursepick_jscript {
     my $verify_script = <<"END";
-<script>
+<script type="text/javascript">
 function verifyCoursePick(caller) {
     var numbutton = getIndex(caller)
     var pickedCourse = document.rolechoice.elements[numbutton+4].value
@@ -970,7 +967,7 @@ END
 
 sub processpick {
     my $process_pick = <<"END";
-<script>
+<script type="text/javascript">
 function process_pick(dom) {
     var pickedCourse=opener.document.rolechoice.$env{'form.cnumelement'}.value;
     var pickedDomain=opener.document.rolechoice.$env{'form.cdomelement'}.value;
