@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Starts a user off based of an existing token.
 #
-# $Id: migrateuser.pm,v 1.10 2007/01/12 15:44:27 raeburn Exp $
+# $Id: migrateuser.pm,v 1.11 2007/09/29 02:09:50 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -87,9 +87,30 @@ sub handler {
     my $extra_env = &sso_check(\%data);
 
     if (!$data{'role'}) {
-	&Apache::lonauth::success($r,$data{'username'},$data{'domain'},
-				  $home,'/adm/roles',$extra_env);
+	# check for exisiting valid session 
+	my %cookies=CGI::Cookie->parse($r->header_in('Cookie'));
+	my $lonid=$cookies{'lonID'};
+	my $handle;
+	if ($lonid) {
+	    $handle=&LONCAPA::clean_handle($lonid->value);
+	}
+	if ($lonid 
+	    && -e $r->dir_config('lonIDsDir').'/'.$handle.'.id' 
+	    && $handle ne '') {
+	    &Apache::lonnet::transfer_profile_to_env($r->dir_config('lonIDsDir'),
+						     $handle);
+	    if ($env{'request.course.id'}) {
+		$r->internal_redirect('/adm/navmaps');
+	    } else {
+		$r->internal_redirect('/adm/roles');
+	    }
+	} else {
+	    &Apache::lonauth::success($r,$data{'username'},$data{'domain'},
+				      $home,'/adm/roles',$extra_env);
+
+	}
 	return OK;
+
     }
 
     my $next_url='/adm/roles?selectrole=1&amp;'.&escape($data{'role'}).'=1';
