@@ -1,6 +1,6 @@
 # functions to glue school database system into Lon-CAPA for 
 # automated enrollment
-# $Id: localenroll.pm,v 1.21 2007/07/25 20:43:48 raeburn Exp $
+# $Id: localenroll.pm,v 1.24 2007/08/31 12:33:35 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -496,7 +496,8 @@ sub instcode_defaults {
 #                keys will be unique IDs (student or faculty/staff ID)
 #                values will be either: scalar (username) or an array 
 #                if a single ID matches multiple usernames.
-# returns 1 parameter - ('ok' or other value).
+# returns 1 parameter - 'ok' if no processing error, or other value 
+#                       if an error occurred.
 # side effects - populates the $instusers and $instids refs to hashes.
 #                with information for all users from all available 
 #                institutional datafeeds.
@@ -512,10 +513,16 @@ sub allusers_info {
 ###############################
 # sub get_userinfo
 #
-# Incoming data: four required arguments and t optional arguments
-# Retrieves institutional data for a single user either by username
-# if $uname is included as second argument, or by ID if $id is 
-# included as a third argument.  Either (b) or (c) must be provided. 
+# Incoming data: four required arguments and additional optional arguments
+# Two modes of operation:
+# (1) Retrieves institutional data for a single user either by username
+#     if $uname is included as second argument, or by ID if $id is 
+#     included as a third argument.  Either (b) or (c) must be provided.
+#     (g), (h) and (i) will be undefined.
+# (2) Retrieves institutional user data from search of an institutional
+#     directory based on a search. (g) and (h) are required.
+#     (i) is optional. (b) and (c) will be undefined. 
+#
 # (a) $dom - domain
 # (b) $uname - username of user
 # (c) $id - student/faculty ID of user
@@ -537,20 +544,29 @@ sub allusers_info {
 #               2. lastname; 3. username
 # (h) $srchterm - optional if $uname or $id defined, otherwise required
 #                String to search for.
-# (i) $srchtype - optional. Allowed value: contains
+# (i) $srchtype - optional. Allowed values: contains, begins (defaults
+#                to exact match otherwise).
 #
-# returns 1 parameter - ('ok' or other value).
+# returns 1 parameter - 'ok' if no processing error, or other value 
+#                       if an error occurred.
 # side effects - populates the $instusers and $instids refs to hashes.
 #                with information for specified username, or specified
 #                id, if fifth argument provided, from all available, or 
 #                specified (e.g., faculty only) institutional datafeeds,
 #                if sixth argument provided.
+#
+# WARNING: You need to set $outcome to 'ok' once you have customized
+#          this routine to communicate with an instititional 
+#          directory data source, otherwise institutional directory 
+#          searches will always be reported as being unavailable
+#          in domain $dom.
+#
 ###############################
 
 sub get_userinfo {
     my ($dom,$uname,$id,$instusers,$instids,$types,
         $srchby,$srchterm,$srchtype) = @_;
-    my $outcome = 'ok';
+    my $outcome = 'unavailable';
     return $outcome;
 }
 
@@ -567,7 +583,8 @@ sub get_userinfo {
 #              which institutional types should be shown
 #              when displaying data tables (e.g., default quotas    
 #              or updateable user fields (see domainprefs.pm) 
-# returns 1 parameter - ('ok' or other value).
+# returns 1 parameter - 'ok' if no processing error, or other value 
+#                        if an error occurred.
 #
 ###############################
 
