@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # edit mode helpers
 #
-# $Id: edit.pm,v 1.106 2007/05/22 01:03:35 albertel Exp $
+# $Id: edit.pm,v 1.108 2007/06/19 20:24:42 banghart Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -920,7 +920,7 @@ sub deletecoorddata {
 #----------------------------------------------------- browse
 sub browse {
     # insert a link to call up the filesystem browser (lonindexer)
-    my ($id, $mode, $titleid) = @_;
+    my ($id, $mode, $titleid, $only) = @_;
     my $form    = 'lonhomework';
     my $element;
     if (! defined($mode) || $mode eq 'attribute') {
@@ -931,7 +931,9 @@ sub browse {
     }
     my $titleelement;
     if ($titleid) {
-	$titleelement=",'','','".&escape("$titleid\_$Apache::lonxml::curdepth")."'";
+	$titleelement=",'$only','','".&escape("$titleid\_$Apache::lonxml::curdepth")."'";
+    } else {
+        $titleelement=",'$only'";
     }
     my $result = <<"ENDBUTTON";
 <a href=\"javascript:openbrowser('$form','$element'$titleelement)\"\>Select</a>
