@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Souce Code handler
 #
-# $Id: lonsource.pm,v 1.18 2007/07/11 20:32:15 albertel Exp $
+# $Id: lonsource.pm,v 1.19 2007/08/28 22:23:22 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -76,7 +76,7 @@ sub copy_stage {
     my $author_name;
 #Figure out if we are author or co-author
 
-    if($env{'request.role'} =~ m|ca.|) {
+    if ($env{'request.role'} =~ m{^ca\.}) {
         ($role, $domain, $author_name) = split(/\//,$env{'request.role'});
     } else {
         $role = "au.";
