@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 # CGI-script to run LaTeX, dvips, ps2ps, ps2pdf etc.
 #
-# $Id: printout.pl,v 1.125 2007/05/10 09:53:39 foxr Exp $
+# $Id: printout.pl,v 1.127 2007/09/21 21:11:20 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -523,7 +523,7 @@ foreach $texfile (@texfile) {
 	      if ($tableofindex eq 'yes') {
 		  my $idxname = $latex_file;
 		  $idxname =~ s/\.tex$/\.idx/;
-		  &busy_wait_command("makindex $idxname",
+		  &busy_wait_command("makeindex $idxname",
 				     "Re-creating index file",
 				     \%prog_state, $idxname);
 		  &busy_wait_command("latex $latex_file 1>/dev/null 2>/dev/null",
@@ -868,7 +868,7 @@ sub repaginate {
 	#  bottom of the page, m the page number within the document.
 	#
 
-	if ($line =~ /^%%Page:/) {
+	if ($line =~ /^%%Page:\s+\d+\s+\d+/) {
 	    my @pageinfo = split(/\s+/, $line);
 	    if ($page_number < $pageinfo[1]) {
 		$page_number = $pageinfo[1];
