@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # <script> definiton
 #
-# $Id: scripttag.pm,v 1.142 2007/08/03 23:29:54 albertel Exp $
+# $Id: scripttag.pm,v 1.143 2007/08/30 22:56:43 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -80,13 +80,21 @@ sub end_LONCAPA_INTERNAL_TURN_STYLE_OFF {
     return ('','no');
 }
 
+=pod 
+
+=item start_LONCAPA_INTERNAL_LONHTTPD_PORT
+
+emits a pice of javascript that says a global js variable to the
+current lonhttp port, currently used by the remote control to find out
+where to load images from
+
+=cut
+
 sub start_LONCAPA_INTERNAL_LONHTTPD_PORT {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval)=@_;
     if ($target eq 'web' || $target eq 'webgrade') {
-	my $lonhttpdPort=$Apache::lonnet::perlvar{'lonhttpdPort'};
-	if (!defined($lonhttpdPort)) { $lonhttpdPort='8080'; }
 	return '<script type="text/javascript">var lonhttpdport=\''.
-	    $lonhttpdPort.'\';</script>';
+	    &Apache::loncommon::lonhttpd_port().'\';</script>';
     }
     return ('','no');
 }
