@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Construct and maintain state and binary representation of course for user
 #
-# $Id: lonuserstate.pm,v 1.119 2007/06/28 22:16:53 albertel Exp $
+# $Id: lonuserstate.pm,v 1.119.2.1 2007/10/29 18:51:00 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -234,7 +234,9 @@ sub loadmap {
                     my $rid=$lpc.'.'.$token->[2]->{'id'};
 
                     $hash{'kind_'.$rid}='cond';
-                    $cond[$#cond+1]=$token->[2]->{'value'};
+		    my $condition = $token->[2]->{'value'};
+		    $condition =~ s/[\n\r]+/ /gs; 
+                    push(@cond, $condition);
                     $hash{'condid_'.$rid}=$#cond;
                     if ($token->[2]->{'type'}) {
                         $cond[$#cond].=':'.$token->[2]->{'type'};
